package com.ynet.life.base;

import com.ynet.gene.data.IndexedCollection;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

/* loaded from: com_ynet_life_base.jar:com/ynet/life/base/LifeBeanRefUtil.class */
public class LifeBeanRefUtil {
    public static Map<String, Object> getFieldValueMap(Object bean) {
        Class<?> cls = bean.getClass();
        Map<String, Object> valueMap = new HashMap<>();
        Method[] methods = cls.getDeclaredMethods();
        for (Field field : cls.getDeclaredFields()) {
            try {
                String fieldType = field.getType().getSimpleName();
                String fieldGetName = parGetName(field.getName());
                if (checkGetMet(methods, fieldGetName)) {
                    Object fieldVal = cls.getMethod(fieldGetName, new Class[0]).invoke(bean, new Object[0]);
                    String result = null;
                    if ("Date".equals(fieldType)) {
                        result = fmtDate((Date) fieldVal);
                    } else if (fieldVal != null) {
                        result = String.valueOf(fieldVal);
                    }
                    valueMap.put(field.getName(), result);
                }
            } catch (Exception unused) {
            }
        }
        return valueMap;
    }

    public static void setFieldValue(Object bean, Map<String, Object> valMap) {
        Class<?> cls = bean.getClass();
        Method[] methods = cls.getDeclaredMethods();
        for (Field field : cls.getDeclaredFields()) {
            try {
                String name = field.getName();
                String fieldSetName = parSetName(name);
                if (checkSetMet(methods, fieldSetName)) {
                    Method fieldSetMet = cls.getMethod(fieldSetName, field.getType());
                    Object value = valMap.get(name);
                    if (value != null && !"".equals(value) && !name.equals("serialVersionUID")) {
                        String fieldType = field.getType().getSimpleName();
                        if ("String".equals(fieldType)) {
                            fieldSetMet.invoke(bean, value);
                        } else if ("Date".equals(fieldType)) {
                            Date temp = parseDate(value.toString());
                            fieldSetMet.invoke(bean, temp);
                        } else if ("Integer".equals(fieldType) || "int".equals(fieldType)) {
                            Integer intval = Integer.valueOf(Integer.parseInt(value.toString()));
                            fieldSetMet.invoke(bean, intval);
                        } else if ("Long".equalsIgnoreCase(fieldType)) {
                            Long temp2 = Long.valueOf(Long.parseLong(value.toString()));
                            fieldSetMet.invoke(bean, temp2);
                        } else if ("Double".equalsIgnoreCase(fieldType)) {
                            Double temp3 = Double.valueOf(Double.parseDouble(value.toString()));
                            fieldSetMet.invoke(bean, temp3);
                        } else if ("Boolean".equalsIgnoreCase(fieldType)) {
                            Boolean temp4 = Boolean.valueOf(Boolean.parseBoolean(value.toString()));
                            fieldSetMet.invoke(bean, temp4);
                        } else if ("IndexedCollection".equalsIgnoreCase(fieldType)) {
                            IndexedCollection coll = parseIndexedCollection(value);
                            fieldSetMet.invoke(bean, coll);
                        } else {
                            System.out.println("not supper type ".concat(String.valueOf(fieldType)));
                        }
                    }
                }
            } catch (Exception unused) {
            }
        }
    }

    public static Date parseDate(String datestr) {
        String fmtstr;
        if (datestr == null || "".equals(datestr)) {
            return null;
        }
        try {
            if (datestr.indexOf(58) > 0) {
                fmtstr = "yyyy-MM-dd HH:mm:ss";
            } else {
                fmtstr = "yyyy-MM-dd";
            }
            return new SimpleDateFormat(fmtstr, Locale.UK).parse(datestr);
        } catch (Exception unused) {
            return null;
        }
    }

    public static IndexedCollection parseIndexedCollection(Object value) {
        IndexedCollection coll = null;
        if (value == null || "".equals(value)) {
            return null;
        }
        if (value instanceof IndexedCollection) {
            coll = (IndexedCollection) value;
        }
        return coll;
    }

    public static String fmtDate(Date date) {
        if (date == null) {
            return null;
        }
        try {
            return new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.US).format(date);
        } catch (Exception unused) {
            return null;
        }
    }

    public static boolean checkSetMet(Method[] methods, String fieldSetMet) {
        for (Method met : methods) {
            if (fieldSetMet.equals(met.getName())) {
                return true;
            }
        }
        return false;
    }

    public static boolean checkGetMet(Method[] methods, String fieldGetMet) {
        for (Method met : methods) {
            if (fieldGetMet.equals(met.getName())) {
                return true;
            }
        }
        return false;
    }

    public static String parGetName(String fieldName) {
        if (fieldName == null || "".equals(fieldName)) {
            return null;
        }
        return "get" + fieldName.substring(0, 1).toUpperCase() + fieldName.substring(1);
    }

    public static String parSetName(String fieldName) {
        if (fieldName == null || "".equals(fieldName)) {
            return null;
        }
        return "set" + fieldName.substring(0, 1).toUpperCase() + fieldName.substring(1);
    }
}
